@@ -25,15 +25,14 @@ void Controller::playVideo(const QString &url, const QString &mediaPlayer) {
         QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
         dbus_iface.call("mime_open", url);
     }
-#endif
 
-//#ifdef Q_WS_X11
-//    QStringList args;
-//    args << "-cache" << "4096" << "-fs" << url;
-//    QProcess *player = new QProcess();
-//    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
-//    player->start("/usr/bin/mplayer", args);
-//#endif
+#else
+    QStringList args;
+    args << "-cache" << "4096" << "-fs" << url;
+    QProcess *player = new QProcess();
+    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
+    player->start("/usr/bin/mplayer", args);
+#endif
 }
 
 void Controller::launchCuteTube() {
